import React, { Suspense, lazy } from "react";
import { Switch, Route, Router } from "wouter";
import { QueryClientProvider } from "@tanstack/react-query";
import { queryClient } from "./lib/queryClient";
import { ErrorBoundary } from 'react-error-boundary';
import MainLayout from "@/components/layout/main-layout";

// Lazy loaded components
const Home = lazy(() => import("./pages/home-new"));
const About = lazy(() => import("./pages/about"));
const Services = lazy(() => import("./pages/services"));
const Contact = lazy(() => import("./pages/contact"));
const FAQ = lazy(() => import("./pages/faq"));
const Pricing = lazy(() => import("./pages/pricing-fixed-new"));
const PricingNew = lazy(() => import("./pages/pricing-new"));
const StripePricing = lazy(() => import("./pages/stripe-pricing"));
const Resources = lazy(() => import("./pages/resources"));
const Jobs = lazy(() => import("./pages/jobs-new"));
const QRCode = lazy(() => import("./pages/qrcode"));
const Login = lazy(() => import("./pages/login"));

// Admin pages
const AdminDashboard = lazy(() => import("./pages/admin/dashboard-new"));
const AdminInquiries = lazy(() => import("./pages/admin/inquiries"));
const AdminSettings = lazy(() => import("./pages/admin/settings"));

// Legal pages
const TermsOfService = lazy(() => import("./pages/legal/terms"));
const PrivacyPolicy = lazy(() => import("./pages/legal/privacy"));
const CookiePolicy = lazy(() => import("./pages/legal/cookies"));

// Tool pages
const CareerPath = lazy(() => import("./pages/tools/career-path"));
const CareerPathFullscreen = lazy(() => import("./pages/tools/career-path-fullscreen"));
// Compensation tools removed - Job Market Insights used instead
const HRHealthCheck = lazy(() => import("./pages/tools/hr-health-check"));
const RecruitmentCalculator = lazy(() => import("./pages/tools/recruitment-calculator"));
const TeamStructure = lazy(() => import("./pages/tools/team-structure-generator-modern"));
const TeamBuilder = lazy(() => import("./pages/tools/team-builder"));
const StripeTeamBuilder = lazy(() => import("./pages/tools/stripe-team-builder"));
const WorkforcePlanning = lazy(() => import("./pages/tools/workforce-planning"));

// Simple Stripe-styled components - standalone implementations
const SimpleCareerPath = lazy(() => import("./pages/tools/simple-career-path"));
// Simple Compensation removed - Job Market Insights used instead
const SimpleHRHealthCheck = lazy(() => import("./pages/tools/simple-hr-health-check"));
// Import the full JobMarketInsights component
const JobMarketInsights = lazy(() => import("./pages/tools/job-market-insights"));
const ToolsShowcase = lazy(() => import("./pages/tools-showcase"));

// Modern redesigned components
const CareerPathModern = lazy(() => import("./pages/tools/career-path-modern"));

const NotFound = lazy(() => import("./pages/not-found"));

// Error fallback component
const ErrorFallback = ({ error, resetErrorBoundary }: { error: Error; resetErrorBoundary: () => void }) => (
  <div className="flex items-center justify-center min-h-screen">
    <div className="text-center p-6 bg-white rounded-lg shadow-lg">
      <h2 className="text-2xl mb-4">Something went wrong</h2>
      <p className="mb-4 text-red-500">{error.message}</p>
      <button
        onClick={resetErrorBoundary}
        className="px-4 py-2 bg-blue-500 text-white rounded hover:bg-blue-600"
      >
        Try again
      </button>
    </div>
  </div>
);

// Loading component
const LoadingSpinner = () => (
  <div className="flex items-center justify-center min-h-screen">
    <div className="loader"></div>
  </div>
);



// Main Routes component
function Routes() {
  return (
    <ErrorBoundary FallbackComponent={ErrorFallback}>
      <Suspense fallback={<LoadingSpinner />}>
        <Switch>
          {/* Login Page */}
          <Route path="/login">
            <Login />
          </Route>
          
          {/* Admin Pages */}
          <Route path="/admin/dashboard">
            <AdminDashboard />
          </Route>
          <Route path="/admin/inquiries">
            <AdminInquiries />
          </Route>
          <Route path="/admin/settings">
            <AdminSettings />
          </Route>
          
          {/* Home Page */}
          <Route path="/">
            <MainLayout>
              <Home />
            </MainLayout>
          </Route>
          
          {/* Regular pages with MainLayout */}
          <Route path="/about">
            <MainLayout>
              <About />
            </MainLayout>
          </Route>
          
          <Route path="/services">
            <MainLayout>
              <Services />
            </MainLayout>
          </Route>
          
          <Route path="/contact">
            <MainLayout>
              <Contact />
            </MainLayout>
          </Route>
          
          <Route path="/faq">
            <MainLayout>
              <FAQ />
            </MainLayout>
          </Route>
          
          <Route path="/pricing">
            <MainLayout>
              <Pricing />
            </MainLayout>
          </Route>
          
          <Route path="/pricing-new">
            <MainLayout>
              <PricingNew />
            </MainLayout>
          </Route>
          
          <Route path="/stripe-pricing">
            <StripePricing />
          </Route>
          
          <Route path="/resources">
            <MainLayout>
              <Resources />
            </MainLayout>
          </Route>
          
          <Route path="/jobs">
            <MainLayout>
              <Jobs />
            </MainLayout>
          </Route>
          
          <Route path="/qrcode">
            <MainLayout>
              <QRCode />
            </MainLayout>
          </Route>
          
          {/* Legal Pages */}
          <Route path="/legal/terms">
            <MainLayout>
              <TermsOfService />
            </MainLayout>
          </Route>
          
          <Route path="/legal/privacy">
            <MainLayout>
              <PrivacyPolicy />
            </MainLayout>
          </Route>
          
          <Route path="/legal/cookies">
            <MainLayout>
              <CookiePolicy />
            </MainLayout>
          </Route>
          
          {/* Tool Pages */}
          <Route path="/tools/career-path">
            <MainLayout>
              <CareerPathFullscreen />
            </MainLayout>
          </Route>
          
          {/* Compensation Benchmarking routes removed - Job Market Insights used instead */}
          
          <Route path="/tools/hr-health-check">
            <MainLayout>
              <HRHealthCheck />
            </MainLayout>
          </Route>
          
          <Route path="/tools/recruitment-calculator">
            <MainLayout>
              <RecruitmentCalculator />
            </MainLayout>
          </Route>
          
          <Route path="/tools/team-structure-generator">
            <MainLayout>
              <TeamStructure />
            </MainLayout>
          </Route>
          
          <Route path="/tools/team-structure-fixed">
            <MainLayout>
              <div className="bg-white">
                {/* Blue Gradient Hero Section */}
                <div className="bg-gradient-to-r from-blue-500 to-blue-600 w-full overflow-hidden relative">
                  <div className="absolute inset-0 opacity-20 bg-[url('data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjAiIGhlaWdodD0iMjAiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGNpcmNsZSBjeD0iMSIgY3k9IjEiIHI9IjEiIGZpbGw9InJnYmEoMCwwLDAsMC4wMikiLz48L3N2Zz4=')] bg-[size:20px_20px]"></div>
                  
                  <div className="w-full mx-auto max-w-7xl px-4 sm:px-6 lg:px-8 py-12 sm:py-16 relative">
                    <div className="text-center">
                      <div className="inline-flex items-center gap-2 rounded-full bg-white/90 px-4 py-1.5 text-xs font-medium text-blue-600 mb-4 shadow-sm ring-1 ring-blue-100">
                        <span>Team planning</span>
                      </div>
                      <h1 className="text-4xl md:text-5xl font-bold text-white mb-4">
                        <span className="text-white">Team Structure</span> Generator
                      </h1>
                      <p className="text-lg text-white max-w-2xl mx-auto">
                        Get personalized recommendations for building your ideal startup team based on your industry, size, and goals.
                      </p>
                    </div>
                  </div>
                </div>
                
                <div className="w-full px-3 md:px-5 py-12 -mt-6 relative z-20">
                  {/* Route to original component for content */}
                  <TeamStructure />
                </div>
              </div>
            </MainLayout>
          </Route>
          
          <Route path="/tools/team-builder">
            <MainLayout>
              <div className="bg-white">
                {/* Blue Gradient Hero Section */}
                <div className="bg-gradient-to-r from-blue-500 to-blue-600 w-full overflow-hidden relative">
                  <div className="absolute inset-0 opacity-20 bg-[url('data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjAiIGhlaWdodD0iMjAiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGNpcmNsZSBjeD0iMSIgY3k9IjEiIHI9IjEiIGZpbGw9InJnYmEoMCwwLDAsMC4wMikiLz48L3N2Zz4=')] bg-[size:20px_20px]"></div>
                  
                  <div className="w-full mx-auto max-w-7xl px-4 sm:px-6 lg:px-8 py-12 sm:py-16 relative">
                    <div className="text-center">
                      <div className="inline-flex items-center gap-2 rounded-full bg-white/90 px-4 py-1.5 text-xs font-medium text-blue-600 mb-4 shadow-sm ring-1 ring-blue-100">
                        <span>Team planning</span>
                      </div>
                      <h1 className="text-4xl md:text-5xl font-bold text-white mb-4">
                        <span className="text-white">Team Structure</span> Generator
                      </h1>
                      <p className="text-lg text-white max-w-2xl mx-auto">
                        Get personalized recommendations for building your ideal startup team based on your industry, size, and goals.
                      </p>
                    </div>
                  </div>
                </div>
                
                <TeamBuilder />
              </div>
            </MainLayout>
          </Route>
          
          <Route path="/tools/stripe-team-builder">
            <MainLayout>
              <StripeTeamBuilder />
            </MainLayout>
          </Route>
          
          {/* NEW SIMPLIFIED STRIPE STYLED PAGES */}
          <Route path="/tools/career-path-stripe">
            <MainLayout>
              <SimpleCareerPath />
            </MainLayout>
          </Route>
          
          {/* Compensation benchmarking stripe route removed - Job Market Insights used instead */}
          
          <Route path="/tools/hr-health-check-stripe">
            <MainLayout>
              <SimpleHRHealthCheck />
            </MainLayout>
          </Route>
          
          <Route path="/tools/job-market-insights">
            <MainLayout>
              <JobMarketInsights />
            </MainLayout>
          </Route>
          
          <Route path="/tools/workforce-planning">
            <MainLayout>
              <WorkforcePlanning />
            </MainLayout>
          </Route>
          
          {/* Compensation tool routes removed - Job Market Insights used instead */}
          
          <Route path="/tools-showcase">
            <MainLayout>
              <ToolsShowcase />
            </MainLayout>
          </Route>
          
          {/* Career Path Modern route - kept for compatibility */}
          <Route path="/tools/career-path-modern">
            <MainLayout>
              <CareerPathModern />
            </MainLayout>
          </Route>
          
          {/* 404 catch-all - should come last */}
          <Route>
            <MainLayout>
              <NotFound />
            </MainLayout>
          </Route>
        </Switch>
      </Suspense>
    </ErrorBoundary>
  );
}

// Main App component
function App() {
  return (
    <React.StrictMode>
      <QueryClientProvider client={queryClient}>
        <Router>
          <Routes />
        </Router>
      </QueryClientProvider>
    </React.StrictMode>
  );
};

export default App;